health_operator

Function health_operator 

pub(crate) fn health_operator<'scope, T: Timestamp, P>(
    scope: Scope<'scope, T>,
    now: NowFn,
    mark_starting: BTreeSet<GlobalId>,
    halting_id: GlobalId,
    object_type: &'static str,
    health_stream: StreamVec<'scope, T, HealthStatusMessage>,
    health_operator_impl: P,
    write_namespaced_map: bool,
    suspend_and_restart_delay: Duration,
) -> PressOnDropButton
where P: HealthOperator + 'static,
Writes updates that come across health_stream to the collection’s status shards, as identified by their CollectionMetadata.

Only one worker will be active and write to the status shard.

The OutputIndex values that come across health_stream must be a strict subset of those in configs’s keys.