render_sink

Function render_sink 

pub(crate) fn render_sink<'scope>(
    scope: Scope<'scope, ()>,
    storage_state: &mut StorageState,
    sink_id: GlobalId,
    sink: &StorageSinkDesc<CollectionMetadata, Timestamp>,
) -> (StreamVec<'scope, (), HealthStatusMessage>, Vec<PressOnDropButton>)
Renders complete differential collections that represent the sink and its errors as requested by the original CREATE SINK statement.