fn mint_batch_descriptions<'scope, D>(
name: String,
sink_id: GlobalId,
input: VecCollection<'scope, Timestamp, D, Diff>,
sink: &StorageSinkDesc<CollectionMetadata, Timestamp>,
connection: IcebergSinkConnection,
storage_configuration: StorageConfiguration,
initial_schema: SchemaRef,
) -> (VecCollection<'scope, Timestamp, D, Diff>, StreamVec<'scope, Timestamp, (Antichain<Timestamp>, Antichain<Timestamp>)>, StreamVec<'scope, Timestamp, Infallible>, StreamVec<'scope, Timestamp, HealthStatusMessage>, PressOnDropButton)where
D: Clone + 'static,Expand description
Generate time-based batch boundaries for grouping writes into Iceberg snapshots. Batches are minted with configurable windows to balance write efficiency with latency. We maintain a sliding window of future batch descriptions so writers can start processing data even while earlier batches are still being written.