fn synthesize_probes<'scope, T: Timestamp>(
source_id: GlobalId,
progress: StreamVec<'scope, T, Infallible>,
interval: Duration,
now_fn: NowFn,
) -> StreamVec<'scope, T, Probe<T>>Expand description
Synthesizes a probe stream that produces the frontier of the given progress stream at the given interval.
This is used as a fallback for sources that don’t support probing the frontier of the upstream system.