render_reader

Function render_reader 

fn render_reader<'scope>(
    scope: Scope<'scope, KafkaTimestamp>,
    connection: KafkaSourceConnection,
    config: RawSourceCreationConfig,
    resume_uppers: impl Stream<Item = Antichain<KafkaTimestamp>> + 'static,
    metadata_stream: StreamVec<'scope, KafkaTimestamp, (Timestamp, MetadataUpdate)>,
    start_signal: impl Future<Output = ()> + 'static,
) -> (StackedCollection<'scope, KafkaTimestamp, (usize, Result<SourceMessage, DataflowError>)>, StreamVec<'scope, KafkaTimestamp, HealthStatusMessage>, PressOnDropButton)
Render the reader of a Kafka source.

The reader is responsible for polling the Kafka topic partitions for new messages, and transforming them into a SourceMessage collection.