fn source_render_operator<'scope, C>(
scope: Scope<'scope, C::Time>,
config: &RawSourceCreationConfig,
source_connection: C,
probed_upper_tx: Sender<Option<Probe<C::Time>>>,
resume_uppers: impl Stream<Item = Antichain<C::Time>> + 'static,
start_signal: impl Future<Output = ()> + 'static,
) -> (BTreeMap<GlobalId, StackedCollection<'scope, C::Time, Result<SourceMessage, DataflowError>>>, StreamVec<'scope, C::Time, HealthStatusMessage>, Vec<PressOnDropButton>)where
C: SourceRender + 'static,Expand description
Renders the source dataflow fragment from the given SourceConnection. This returns a collection timestamped with the source specific timestamp type.