SinkStatistics

Type Alias SinkStatistics 

pub type SinkStatistics = StorageStatistics<SinkStatisticsRecord, SinkStatisticsMetrics, ()>;
Statistics maintained for sinks.

Aliased Type

pub struct SinkStatistics { /* private fields */ }

Implementations

Source

impl SinkStatistics

pub fn reset_gauges(&self)

Reset gauges to uninitialized state. This does not reset prometheus gauges, which will be overwritten with new values.

pub fn snapshot(&self) -> Option<SinkStatisticsRecord>

Get a snapshot of the data, returning None if all gauges are not initialized.

This also resets counters, so that we continue to move diffs around.

pub fn inc_messages_staged_by(&self, value: u64)

Increment the messages_staged stat.

pub fn inc_bytes_staged_by(&self, value: u64)

Increment the bytes_received stat.

pub fn inc_messages_committed_by(&self, value: u64)

Increment the messages_committed stat.

pub fn inc_bytes_committed_by(&self, value: u64)

Increment the bytes_committed stat.