drain_sealed_input

Function drain_sealed_input 

fn drain_sealed_input<T, FromTime>(
    sealed: Vec<Vec<(UpsertKey, T, UpsertDiff<FromTime>)>>,
    ineligible: &mut Vec<(UpsertKey, T, UpsertDiff<FromTime>)>,
    output: &mut Vec<(Result<Row, Box<UpsertError>>, T, Diff)>,
    persist_upper: &Antichain<T>,
    trace: &mut TraceAgent<ValSpine<UpsertKey, Result<Row, Box<UpsertError>>, T, Diff>>,
    worker_id: &usize,
    source_id: &GlobalId,
) -> DrainStats
Process sealed chunks from the batcher. Entries at the persist frontier are eligible for processing (cursor lookup + output); all others are returned in ineligible for re-stashing.

The sealed chunks are already sorted and consolidated by the MergeBatcher.