pub fn render_decode_cdcv2<'scope, FromTime: Timestamp>(
input: &VecCollection<'scope, Timestamp, DecodeResult<FromTime>, Diff>,
) -> (VecCollection<'scope, Timestamp, Row, Diff>, PressOnDropButton)Expand description
Decode delimited CDCv2 messages.
This not only literally decodes the avro-encoded messages, but also builds a differential dataflow collection that respects the data and progress messages in the underlying CDCv2 stream.