fn source_render_operator<G, C>(
scope: &mut G,
config: &RawSourceCreationConfig,
source_connection: C,
probed_upper_tx: Sender<Option<Probe<C::Time>>>,
resume_uppers: impl Stream<Item = Antichain<C::Time>> + 'static,
start_signal: impl Future<Output = ()> + 'static,
) -> (BTreeMap<GlobalId, StackedCollection<G, Result<SourceMessage, DataflowError>>>, StreamVec<G, HealthStatusMessage>, Vec<PressOnDropButton>)Expand description
Renders the source dataflow fragment from the given SourceConnection. This returns a collection timestamped with the source specific timestamp type.