pub fn rehydration_finished<'scope, T: Timestamp>(
scope: Scope<'scope, T>,
source_config: &RawSourceCreationConfig,
token: impl Any + 'static,
resume_upper: Antichain<T>,
input: StreamVec<'scope, T, Infallible>,
)Expand description
This leaf operator drops token after the input reaches the resume_upper.
This is useful to take coordinated actions across all workers, after the upsert
operator has rehydrated.